DnsBuilder

Struct DnsBuilder 

pub struct DnsBuilder { /* private fields */ }
Fluent builder for DnsConfig.

Implementations

Source

impl DnsBuilder

pub fn new() -> Self

Start building DNS configuration with defaults.

pub fn rebind_protection(self, enabled: bool) -> Self

Enable or disable DNS rebinding protection. Default: true.

pub fn nameservers<I>(self, nameservers: I) -> Self

Set the upstream nameservers to forward queries to. When one or more are set, the interceptor uses these instead of the nameservers in the host’s /etc/resolv.conf. Replaces any previously-set nameservers. Each element is any type convertible into Nameserver (SocketAddr, IpAddr, or a parsed string via "dns.google:53".parse::<Nameserver>()?).

pub fn query_timeout_ms(self, ms: u64) -> Self

Set the per-DNS-query timeout in milliseconds. Default: 5000.

pub fn build(self) -> DnsConfig

Consume the builder and return the configuration.