RateLimiterBuilder

Struct RateLimiterBuilder 

pub struct RateLimiterBuilder { /* private fields */ }
Fluent builder for one direction’s RateLimiterConfig.

.egress(|r| r
    .bandwidth(1.mib(), Duration::from_secs(1))
    .bandwidth_burst(512.kib())
    .ops(1_000, Duration::from_secs(1))
    .ops_burst(500)
)

Implementations

Source

impl RateLimiterBuilder

pub fn bandwidth(self, size: impl Into<Bytes>, refill_time: Duration) -> Self

Cap bandwidth at size bytes per refill_time.

refill_time must be at least one millisecond and exactly representable as a whole number of milliseconds.

.bandwidth(1.mib(), Duration::from_secs(1))
pub fn bandwidth_burst(self, burst: impl Into<Bytes>) -> Self

Grant a one-time startup burst of burst bytes on top of the bandwidth bucket. Requires bandwidth.

pub fn ops(self, count: u64, refill_time: Duration) -> Self

Cap packet rate at count frames per refill_time.

refill_time must be at least one millisecond and exactly representable as a whole number of milliseconds.

.ops(1_000, Duration::from_secs(1))
pub fn ops_burst(self, count: u64) -> Self

Grant a one-time startup burst of count frames on top of the ops bucket. Requires ops.

pub fn build(self) -> Result<RateLimiterConfig, BuildError>

Consume the builder and return the validated configuration.