pub struct ViolationActionBuilder { /* private fields */ }Expand description
Fluent builder for a ViolationAction.
Implementations
Sourceimpl ViolationActionBuilder
impl ViolationActionBuilder
Sourcepub fn from_action(action: ViolationAction) -> Self
pub fn from_action(action: ViolationAction) -> Self
Start building from an existing action.
Sourcepub fn block_and_log(self) -> Self
pub fn block_and_log(self) -> Self
Block the request and emit a warning log.
Sourcepub fn block_and_terminate(self) -> Self
pub fn block_and_terminate(self) -> Self
Block the request and terminate the sandbox.
Sourcepub fn passthrough_host(self, host: impl Into<String>) -> Self
pub fn passthrough_host(self, host: impl Into<String>) -> Self
Allow a host to receive secret placeholders without substitution.
Sourcepub fn passthrough_host_pattern(self, pattern: impl Into<String>) -> Self
pub fn passthrough_host_pattern(self, pattern: impl Into<String>) -> Self
Allow hosts matching a wildcard pattern to receive secret placeholders without substitution.
Sourcepub fn passthrough_all_hosts(self, i_understand_the_risk: bool) -> Self
pub fn passthrough_all_hosts(self, i_understand_the_risk: bool) -> Self
Allow any host to receive secret placeholders without substitution.
Sourcepub fn build(self) -> ViolationAction
pub fn build(self) -> ViolationAction
Consume the builder and return the action.