pub enum ConnectionLimit {
Unlimited,
Limited(NonZeroUsize),
}Expand description
Explicit connection limit, serialized as zero for unlimited or a positive cap.
Variants
Implementations
Sourceimpl ConnectionLimit
impl ConnectionLimit
Sourcepub const fn cap(self) -> Option<NonZeroUsize>
pub const fn cap(self) -> Option<NonZeroUsize>
Return the effective cap used by the network stack.