#[repr(u8)]pub enum ProxyConnectStatus {
Pending = 0,
Connected = 1,
PolicyDenied = 2,
UpstreamConnectFailed = 3,
}Expand description
Terminal connection status reported by an outbound proxy task.
Variants
Pending = 0
No final proxy connection status has been reported yet.
Connected = 1
The proxy connected to the upstream.
PolicyDenied = 2
The proxy denied the connection before dialing upstream.
UpstreamConnectFailed = 3
The proxy attempted to dial upstream and the connect failed.