pub struct DnsInterceptor { /* private fields */ }Expand description
DNS interceptor that resolves queries via host nameservers.
Implementations
Sourceimpl DnsInterceptor
impl DnsInterceptor
Sourcepub fn new(
filter: DnsFilter,
pin_set: Arc<RwLock<DnsPinSet>>,
gateway_ips: Vec<IpAddr>,
) -> Result<Self>
pub fn new( filter: DnsFilter, pin_set: Arc<RwLock<DnsPinSet>>, gateway_ips: Vec<IpAddr>, ) -> Result<Self>
Creates a new DNS interceptor.
Returns an error if the system DNS resolver configuration cannot be read.
Sourcepub async fn maybe_intercept(
&self,
frame: &ParsedFrame<'_>,
) -> DnsInterceptResult
pub async fn maybe_intercept( &self, frame: &ParsedFrame<'_>, ) -> DnsInterceptResult
Checks if a frame is a DNS query to the gateway and resolves it locally.
Returns NotIntercepted if the frame should continue to the backend,
Intercepted if the frame was consumed locally without a response yet,
or one or more synthesized DNS responses.