pub enum OutboundProxyParseError {
MissingProtocol,
UnsupportedProtocol {
protocol: String,
},
CredentialsNotSupported,
ExtraComponentsNotSupported,
Build(OutboundProxyBuildError),
}Expand description
Error returned when parsing an outbound proxy URI.
URI parsing is intended for string-only interfaces such as the CLI. SDKs
should use OutboundProxyBuilder instead.
Variants
MissingProtocol
The URI does not include a scheme:// prefix.
UnsupportedProtocol
The URI uses a proxy protocol that is not supported yet.
CredentialsNotSupported
The URI includes credentials, which are not supported.
ExtraComponentsNotSupported
The URI includes a path, query, or fragment.
Build(OutboundProxyBuildError)
The proxy address is not a valid socket address.