Module ready

Module ready 

Startup handshake types for the supervisor ↔ msbnet readiness protocol.

msbnet writes a single JSON line to stdout on successful bootstrap. The supervisor parses this line to obtain the resolved network parameters before spawning the VM.

Structs

MsbnetReady
JSON payload written to stdout by msbnet when ready.
MsbnetReadyIpv4
Resolved IPv4 parameters reported by msbnet.
MsbnetReadyIpv6
Resolved IPv6 parameters reported by msbnet.
MsbnetReadyTls
TLS interception readiness info reported by msbnet.