pub struct GatewayIps {
pub ipv4: Option<Ipv4Addr>,
pub ipv6: Option<Ipv6Addr>,
}Expand description
Per-sandbox gateway addresses owned by the smoltcp virtual stack.
Each family is Some when active for this sandbox and None otherwise.
resolve_host_dst rewrites gateway-bound connections to loopback at dial time.
Fields
ipv4: Option<Ipv4Addr>Gateway IPv4.
ipv6: Option<Ipv6Addr>Gateway IPv6.