pub async fn bind_proxy() -> Result<PendingTlsProxy>Expand description
Binds the TLS proxy listener on an OS-assigned port.
Must be called in the privileged phase before dropping privileges.
pub async fn bind_proxy() -> Result<PendingTlsProxy>Binds the TLS proxy listener on an OS-assigned port.
Must be called in the privileged phase before dropping privileges.