Low-level packet processing and smoltcp integration.
Modules
- backend
SmoltcpBackend— libkrunNetBackendimplementation that bridges the NetWorker thread to the smoltcp poll thread via lock-free queues.- device
- Slot-based
smoltcp::phy::Deviceimplementation. - poll
- smoltcp interface setup, frame classification, and poll loop.
- shared
- Shared state between the NetWorker thread, smoltcp poll thread, and tokio proxy tasks.