Bidirectional TCP proxy: smoltcp socket ↔ channels ↔ tokio socket.
Each outbound guest TCP connection gets a proxy task that opens a real TCP connection to the destination via tokio and relays data between the channel pair (connected to the smoltcp socket in the poll loop) and the real server.
Functions
- spawn_
tcp_ proxy - Spawn a TCP proxy task for a newly established connection.